@@ -1,6 +1,7 @@
-#![cfg_attr(nightly, feature(core_intrinsics))]
 #![cfg_attr(all(nightly, test), feature(test))]
 
+extern crate crossbeam;
+
 mod block_node;
 
 pub mod mpmc_bounded;
